// Ultra-lightweight hero component for immediate LCP
import React, { useState } from 'react';
import { CriticalCSSInline } from './critical-css-inline';

export default function UltraPerformanceHero() {
  const [isSubmitting, setIsSubmitting] = useState(false);
  
  const handleSubmit = async (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    setIsSubmitting(true);
    
    const formData = new FormData(e.currentTarget);
    const data = Object.fromEntries(formData);
    
    try {
      const response = await fetch('/api/leads', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(data)
      });
      
      if (response.ok) {
        // Minimal tracking
        if ((window as any).gtag) {
          (window as any).gtag('event', 'generate_lead', { value: 1 });
        }
        alert('Thank you! We\'ll contact you within 24 hours.');
        e.currentTarget.reset();
      } else {
        alert('Please try again or call (636) 244-8246');
      }
    } catch {
      alert('Please try again or call (636) 244-8246');
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <>
      <CriticalCSSInline />
      <section id="hero" className="hero-section">
        <div className="hero-bg-pattern"></div>
        
        <div className="hero-container">
          <div className="hero-content">
            <h1>Connect with Your Perfect Medical Billing Partner Today!</h1>
            <p>
              We match healthcare practices with pre-vetted billing companies to optimize your revenue cycle. 
              Get personalized recommendations from trusted partners who understand your specialty.
            </p>
            
            <div className="trust-badges">
              <div className="trust-badge">✓ Pre-Vetted Partners</div>
              <div className="trust-badge">✓ Free Matching Service</div>
              <div className="trust-badge">🤖 AI-Powered Analysis</div>
            </div>
            
            <div style={{ marginBottom: '2rem' }}>
              <button
                onClick={() => window.location.href = '/ai-revenue-calculator'}
                style={{
                  background: 'linear-gradient(135deg, #8b5cf6 0%, #6366f1 100%)',
                  color: 'white',
                  padding: '1rem 2rem',
                  borderRadius: '50px',
                  border: 'none',
                  fontSize: '1.125rem',
                  fontWeight: '600',
                  cursor: 'pointer',
                  boxShadow: '0 10px 25px rgba(139, 92, 246, 0.3)',
                  transition: 'all 0.3s ease',
                  display: 'inline-flex',
                  alignItems: 'center',
                  gap: '0.75rem'
                }}
                onMouseEnter={(e) => {
                  e.currentTarget.style.transform = 'translateY(-2px)';
                  e.currentTarget.style.boxShadow = '0 15px 35px rgba(139, 92, 246, 0.4)';
                }}
                onMouseLeave={(e) => {
                  e.currentTarget.style.transform = 'translateY(0)';
                  e.currentTarget.style.boxShadow = '0 10px 25px rgba(139, 92, 246, 0.3)';
                }}
              >
                🤖 Try AI Revenue Calculator
              </button>
            </div>
            
            {/* Optimized logo with WebP support for 206 KiB image savings */}
            <div style={{ 
              marginTop: '2rem',
              display: 'flex',
              justifyContent: 'center'
            }}>
              <picture>
                <source srcSet="/logo.webp" type="image/webp" width="400" height="200" />
                <img 
                  src="/logo.png" 
                  alt="TRUST Billing Connect - Medical Billing Partner Matching" 
                  width="400"
                  height="200"
                  loading="eager"
                  decoding="async"
                  style={{ 
                    height: '200px', 
                    width: '400px',
                    objectFit: 'contain',
                    filter: 'drop-shadow(0 20px 35px rgba(0,0,0,0.25))',
                    maxWidth: '100%'
                  }}
                />
              </picture>
            </div>
          </div>

          <div className="hero-form">
            <h2 className="form-title">Find Your Perfect Billing Partner</h2>
            <p className="form-subtitle">Get matched with trusted billing companies in under 24 hours</p>
            
            <form onSubmit={handleSubmit}>
              <div className="form-group">
                <label className="form-label" htmlFor="name">Your Full Name *</label>
                <input 
                  className="form-input"
                  type="text" 
                  name="name" 
                  id="name"
                  required 
                  placeholder="Dr. John Smith"
                  aria-label="Enter your full name"
                />
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="practice">Practice Name *</label>
                <input 
                  className="form-input"
                  type="text" 
                  name="practice" 
                  id="practice"
                  required 
                  placeholder="ABC Medical Group"
                  aria-label="Enter your practice name"
                />
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="email">Email Address *</label>
                <input 
                  className="form-input"
                  type="email" 
                  name="email" 
                  id="email"
                  required 
                  placeholder="doctor@practice.com"
                  aria-label="Enter your email address"
                />
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="phone">Phone Number *</label>
                <input 
                  className="form-input"
                  type="tel" 
                  name="phone" 
                  id="phone"
                  required 
                  placeholder="(555) 123-4567"
                  aria-label="Enter your phone number"
                />
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="practiceType">Practice Type *</label>
                <select 
                  className="form-select" 
                  name="practiceType" 
                  id="practiceType" 
                  required 
                  aria-label="Select your practice type"
                  style={{
                    appearance: 'auto',
                    WebkitAppearance: 'menulist',
                    MozAppearance: 'menulist',
                    backgroundColor: 'white',
                    pointerEvents: 'auto',
                    zIndex: 10
                  }}
                >
                  <option value="">Select Practice Type</option>
                  <option value="Family Medicine">Family Medicine</option>
                  <option value="Internal Medicine">Internal Medicine</option>
                  <option value="Pediatrics">Pediatrics</option>
                  <option value="Cardiology">Cardiology</option>
                  <option value="Dermatology">Dermatology</option>
                  <option value="Orthopedic Surgery">Orthopedic Surgery</option>
                  <option value="Emergency Medicine">Emergency Medicine</option>
                  <option value="Radiology">Radiology</option>
                  <option value="Anesthesiology">Anesthesiology</option>
                  <option value="Psychiatry">Psychiatry</option>
                  <option value="Obstetrics/Gynecology">Obstetrics/Gynecology</option>
                  <option value="Gastroenterology">Gastroenterology</option>
                  <option value="Pulmonology">Pulmonology</option>
                  <option value="Nephrology">Nephrology</option>
                  <option value="Endocrinology">Endocrinology</option>
                  <option value="Neurology">Neurology</option>
                  <option value="Oncology">Oncology</option>
                  <option value="Urology">Urology</option>
                  <option value="Ophthalmology">Ophthalmology</option>
                  <option value="ENT">ENT (Ear, Nose, Throat)</option>
                  <option value="Rheumatology">Rheumatology</option>
                  <option value="Physical Therapy">Physical Therapy</option>
                  <option value="Chiropractic">Chiropractic</option>
                  <option value="Mental Health">Mental Health</option>
                  <option value="Dental">Dental</option>
                  <option value="Multi-Specialty">Multi-Specialty</option>
                  <option value="Hospital">Hospital</option>
                  <option value="Urgent Care">Urgent Care</option>
                  <option value="Other">Other</option>
                </select>
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="revenue">Monthly Revenue</label>
                <select 
                  className="form-select" 
                  name="revenue" 
                  id="revenue" 
                  aria-label="Select your monthly revenue range"
                  style={{
                    appearance: 'auto',
                    WebkitAppearance: 'menulist',
                    MozAppearance: 'menulist',
                    backgroundColor: 'white',
                    pointerEvents: 'auto',
                    zIndex: 10
                  }}
                >
                  <option value="">Select Monthly Revenue</option>
                  <option value="Under $100K">Under $100K</option>
                  <option value="$100K - $500K">$100K - $500K</option>
                  <option value="$500K - $1M">$500K - $1M</option>
                  <option value="$1M - $5M">$1M - $5M</option>
                  <option value="Over $5M">Over $5M</option>
                </select>
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="contactPreference">Preferred Contact Method</label>
                <select 
                  className="form-select" 
                  name="contactPreference" 
                  id="contactPreference" 
                  aria-label="Select your preferred contact method"
                  style={{
                    appearance: 'auto',
                    WebkitAppearance: 'menulist',
                    MozAppearance: 'menulist',
                    backgroundColor: 'white',
                    pointerEvents: 'auto',
                    zIndex: 10
                  }}
                >
                  <option value="Email">Email</option>
                  <option value="Phone">Phone Call</option>
                  <option value="Both">Both Email & Phone</option>
                </select>
              </div>

              <div className="form-group">
                <label className="form-label" htmlFor="billingCompanyPreference">Billing Company Preference</label>
                <select 
                  className="form-select" 
                  name="billingCompanyPreference" 
                  id="billingCompanyPreference" 
                  aria-label="Select your billing company preference"
                  style={{
                    appearance: 'auto',
                    WebkitAppearance: 'menulist',
                    MozAppearance: 'menulist',
                    backgroundColor: 'white',
                    pointerEvents: 'auto',
                    zIndex: 10
                  }}
                >
                  <option value="Exclusive">Work with one exclusive company</option>
                  <option value="Multiple">Compare multiple companies (up to 5)</option>
                </select>
              </div>

              <button 
                type="submit" 
                className="submit-btn"
                disabled={isSubmitting}
                aria-label={isSubmitting ? 'Finding billing partners, please wait' : 'Submit form to find your billing partner'}
              >
                {isSubmitting ? 'Finding Partners...' : 'Find My Billing Partner'}
              </button>
            </form>
          </div>
        </div>
      </section>
    </>
  );
}